@@ -28,7 +28,8 @@
 #
 
 __all__ = [
-    'validate_otp'
+    'validate_otp',
+    'MODHEX'
 ]
 
 from yubiauth.config import settings
@@ -45,6 +46,8 @@ yubico = Yubico(settings['ykval_id'], settings['ykval_secret'],
                 use_https=use_https)
 
 
+MODHEX = 'cbdefghijklnrtuv'
+
 def validate_otp(otp):
     try:
         return yubico.verify(otp)
